@@ -10,7 +10,7 @@ from sqlalchemy_api_handler.bases.errors import ActivityError
 from sqlalchemy_api_handler.utils.datum import columns_in, \
                                                relationships_in, \
                                                synonyms_in
-import sqlalchemy_api_handler.utils.date
+import sqlalchemy_api_handler.utils.date as date_helper
 from sqlalchemy_api_handler.utils.dehumanize import dehumanize_ids_in
 from sqlalchemy_api_handler.utils.humanize import humanize, \
                                                   humanize_ids_in
@@ -26,7 +26,7 @@ class ActivityMixin(object):
 
     @property
     def entityInsertedAt(self):
-        return sqlalchemy_api_handler.utils.date.to_datetime(self.data.get('dateCreated')) or self.entity.dateCreated
+        return date_helper.to_datetime(self.data.get('dateCreated')) or self.entity.dateCreated
 
     @declared_attr
     def tableName(cls):
